|
Boost-Commit : |
From: stipe_at_[hidden]
Date: 2008-08-10 21:03:14
Author: srajko
Date: 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
New Revision: 48073
URL: http://svn.boost.org/trac/boost/changeset/48073
Log:
add framework, entity, traits
Added:
sandbox/dataflow-rewrite/boost/dataflow/generic/entity/
sandbox/dataflow-rewrite/boost/dataflow/generic/entity.hpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/traits.hpp
sandbox/dataflow-rewrite/boost/dataflow/generic/entity/traits_sequence_intrusive_registration.hpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/detail/traits_sequence.hpp
sandbox/dataflow-rewrite/boost/dataflow/generic/framework.hpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/tags.hpp
sandbox/dataflow-rewrite/boost/dataflow/generic/traits.hpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/traits.hpp
sandbox/dataflow-rewrite/boost/dataflow/utility/enable_if_type.hpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/boost/dataflow/utility/enable_if_type.hpp
sandbox/dataflow-rewrite/boost/dataflow/utility/is_type.hpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/boost/dataflow/utility/is_type.hpp
sandbox/dataflow-rewrite/libs/dataflow/test/Jamfile (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/libs/dataflow/test/Jamfile.v2
sandbox/dataflow-rewrite/libs/dataflow/test/generic/
sandbox/dataflow-rewrite/libs/dataflow/test/generic/test_entity.cpp (contents, props changed)
- copied, changed from r47744, /sandbox/SOC/2007/signals/libs/dataflow/test/test_entity.cpp
Text files modified:
sandbox/dataflow-rewrite/Jamroot | 3
sandbox/dataflow-rewrite/boost/dataflow/generic/entity.hpp | 155 +++------------------------------------
sandbox/dataflow-rewrite/boost/dataflow/generic/entity/traits_sequence_intrusive_registration.hpp | 10 +-
sandbox/dataflow-rewrite/boost/dataflow/generic/framework.hpp | 91 ++--------------------
sandbox/dataflow-rewrite/boost/dataflow/generic/traits.hpp | 65 +++++-----------
sandbox/dataflow-rewrite/boost/dataflow/utility/enable_if_type.hpp | 10 +-
sandbox/dataflow-rewrite/boost/dataflow/utility/is_type.hpp | 14 +-
sandbox/dataflow-rewrite/libs/dataflow/build/xcodeide/dataflow.xcodeproj/project.pbxproj | 42 ++++++++++
sandbox/dataflow-rewrite/libs/dataflow/test/Jamfile | 17 ----
sandbox/dataflow-rewrite/libs/dataflow/test/generic/test_entity.cpp | 4
10 files changed, 109 insertions(+), 302 deletions(-)
Modified: sandbox/dataflow-rewrite/Jamroot
==============================================================================
--- sandbox/dataflow-rewrite/Jamroot (original)
+++ sandbox/dataflow-rewrite/Jamroot 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -14,9 +14,6 @@
# record the root of the datalow directory structure
path-constant TOP : . ;
-# point to Boost.Build
-boost-build $(BOOST_ROOT)/tools/build/v2 ;
-
# we are using Boost
use-project boost
: $(BOOST_ROOT)
Copied: sandbox/dataflow-rewrite/boost/dataflow/generic/entity.hpp (from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/traits.hpp)
==============================================================================
--- /sandbox/SOC/2007/signals/boost/dataflow/support/traits.hpp (original)
+++ sandbox/dataflow-rewrite/boost/dataflow/generic/entity.hpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -1,128 +1,24 @@
-// Copyright 2007 Stjepan Rajko.
+// Copyright 2007,8 Stjepan Rajko.
// Distributed under the Boost Software License, Version 1.0. (See
// accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#ifndef BOOST_DATAFLOW_SUPPORT_TRAITS_HPP
-#define BOOST_DATAFLOW_SUPPORT_TRAITS_HPP
+#ifndef BOOST__DATAFLOW__GENERIC__ENTITY_HPP
+#define BOOST__DATAFLOW__GENERIC__ENTITY_HPP
-#include <boost/dataflow/support/tags.hpp>
+#include <boost/dataflow/generic/traits.hpp>
#include <boost/dataflow/utility/enable_if_type.hpp>
-#include <boost/mpl/assert.hpp>
#include <boost/mpl/bool.hpp>
-#include <boost/mpl/is_sequence.hpp>
-#include <boost/type_traits/is_base_of.hpp>
-#include <boost/type_traits/is_same.hpp>
-#include <boost/type_traits/remove_cv.hpp>
-#include <boost/utility/enable_if.hpp>
namespace boost { namespace dataflow {
-/// Convenience class for Traits types.
-template<typename Tag>
-struct traits
-{
- /// The Tag of the port.
- typedef Tag tag;
- /// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_tag<Tag> ));
-};
-
namespace detail {
struct enable_guard;
}
-/// Boolean Metafunction determining whether a type is a Traits.
-template<typename Traits, typename Enable=detail::enable_guard>
-struct is_traits : public mpl::false_
-{
- /// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_same<Enable, detail::enable_guard> ));
-};
-
-/// INTERNAL ONLY
-template<typename Traits>
-struct is_traits<Traits,
- typename utility::enable_if_type<
- utility::all_of<
- typename Traits::tag
- >,
- detail::enable_guard
- >::type>
- : public mpl::true_
-{
- /// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_tag<typename Traits::tag> ));
-};
-
-/// Metafunction returning the Traits of a type.
-template<typename T, typename Tag=default_tag, typename Enable=void>
-struct traits_of
-{
-#ifdef DOXYGEN_DOCS_BUILD
- typedef detail::unspecified type; ///< Traits type.
-#endif
-};
-
-/// INTERNAL ONLY
-/** Specialization allowing intrusive specification of the Traits.
-*/
-template<typename T>
-struct traits_of<
- T,
- typename T::dataflow_traits::tag,
- typename enable_if<
- mpl::not_<mpl::is_sequence<typename T::dataflow_traits> >
- >::type
->
-{
- /// INTERNAL ONLY
- typedef typename T::dataflow_traits type;
- /// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_traits<type> ));
-};
-
-} }
-
-// Specialization allowing intrusive specification of a sequence of Traits.
-#include <boost/dataflow/support/detail/traits_sequence.hpp>
-
-namespace boost { namespace dataflow {
-
-/// Allows registration of Traits for all cv-qualified versions of a type.
-template<typename T, typename Tag=default_tag, typename Enable=void>
-struct register_traits
-{};
-
-
-// Specialization allowing non-intrusive specification of the Traits.
-
-/// INTERNAL ONLY
-template<typename T, typename Tag>
-struct traits_of<
- T,
- Tag,
- typename utility::enable_if_type<
- typename register_traits<
- typename remove_cv<T>::type,
- Tag
- >::type
- >::type
->
-{
- /// INTERNAL ONLY
- typedef
- typename register_traits<
- typename remove_cv<T>::type,
- Tag
- >::type type;
- /// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_traits<type> ));
-};
-
/// Boolean Metafunction determining whether a type has traits.
-template<typename T, typename Tag=default_tag, typename Enable=void>
+template<typename T, typename Framework=default_framework, typename Enable=detail::enable_guard>
struct is_entity : public mpl::false_
{
#ifdef DOXYGEN_DOCS_BUILD
@@ -133,45 +29,22 @@
/// Integral Constant
typedef detail::unspecified type;
#endif
+ /// INTERNAL ONLY
+ BOOST_MPL_ASSERT(( is_same<Enable, detail::enable_guard> ));
};
/// INTERNAL ONLY
-template<typename T, typename Tag>
+template<typename T, typename Framework>
struct is_entity<
T,
- Tag,
- typename utility::enable_if_type<typename traits_of<T, Tag>::type>::type >
+ Framework,
+ typename utility::enable_if_type<
+ typename traits_of<T, Framework>::type,
+ detail::enable_guard
+ >::type>
: public mpl::true_
{};
} } // namespace boost::dataflow
-/// Macro simplifying non-intrusive specification of a type's Traits.
-#define DATAFLOW_TRAITS(Type,Traits) \
-namespace boost { namespace dataflow { \
-template<> \
-struct register_traits< \
- Type, \
- Traits::tag> \
-{ \
- typedef Traits type; \
- BOOST_MPL_ASSERT(( is_traits<type> )); \
-}; \
-}}
-
-/// Macro simplifying non-intrusive specification of multiple types'
-/// Traits, using a boost::enable_if condition.
-#define DATAFLOW_TRAITS_ENABLE_IF(Type,Cond,Traits) \
-namespace boost { namespace dataflow { \
-template<typename Type> \
-struct register_traits< \
- Type, \
- typename Traits::tag, \
- typename boost::enable_if< Cond >::type> \
-{ \
- typedef Traits type; \
- BOOST_MPL_ASSERT(( is_traits<type> )); \
-}; \
-}}
-
-#endif // BOOST_DATAFLOW_SUPPORT_TRAITS_HPP
+#endif // BOOST__DATAFLOW__GENERIC__ENTITY_HPP
Copied: sandbox/dataflow-rewrite/boost/dataflow/generic/entity/traits_sequence_intrusive_registration.hpp (from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/detail/traits_sequence.hpp)
==============================================================================
--- /sandbox/SOC/2007/signals/boost/dataflow/support/detail/traits_sequence.hpp (original)
+++ sandbox/dataflow-rewrite/boost/dataflow/generic/entity/traits_sequence_intrusive_registration.hpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -1,12 +1,12 @@
-// Copyright 2007 Stjepan Rajko.
+// Copyright 2007,2008 Stjepan Rajko.
// Distributed under the Boost Software License, Version 1.0. (See
// accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
#if !BOOST_PP_IS_ITERATING
- #ifndef DATAFLOW_SUPPORT_PORT_TRAITS_SEQUENCE_HPP
- #define DATAFLOW_SUPPORT_PORT_TRAITS_SEQUENCE_HPP
+ #ifndef BOOST__DATAFLOW__GENERIC__ENTITY__TRAITS_SEQUENCE_INTRUSIVE_REGISTRATION_HPP
+ #define BOOST__DATAFLOW__GENERIC__ENTITY__TRAITS_SEQUENCE_INTRUSIVE_REGISTRATION_HPP
#include <boost/preprocessor/iteration/iterate.hpp>
@@ -30,10 +30,10 @@
} }
- #define BOOST_PP_ITERATION_PARAMS_1 (3, (0, 2, <boost/dataflow/support/detail/traits_sequence.hpp>))
+ #define BOOST_PP_ITERATION_PARAMS_1 (3, (0, 2, <boost/dataflow/generic/entity/traits_sequence_intrusive_registration.hpp>))
#include BOOST_PP_ITERATE()
- #endif
+ #endif // BOOST__DATAFLOW__GENERIC__ENTITY__TRAITS_SEQUENCE_INTRUSIVE_REGISTRATION_HPP
#else
Copied: sandbox/dataflow-rewrite/boost/dataflow/generic/framework.hpp (from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/tags.hpp)
==============================================================================
--- /sandbox/SOC/2007/signals/boost/dataflow/utility/enable_if_type.hpp (original)
+++ sandbox/dataflow-rewrite/boost/dataflow/utility/enable_if_type.hpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -3,14 +3,15 @@
// 1.0. (See accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#ifndef DATAFLOW_UTILITY_ENABLE_IF_TYPE_HPP
-#define DATAFLOW_UTILITY_ENABLE_IF_TYPE_HPP
+#ifndef BOOST__DATAFLOW__UTILITY__ENABLE_IF_TYPE_HPP
+#define BOOST__DATAFLOW__UTILITY__ENABLE_IF_TYPE_HPP
namespace boost { namespace dataflow {
namespace utility
{
+
template<typename T, typename Result=void>
struct enable_if_type
{
@@ -24,8 +25,9 @@
struct all_of
{
};
-}
+
+} // namespace utility
} } // namespace boost::dataflow
-#endif // DATAFLOW_UTILITY_ENABLE_IF_TYPE_HPP
+#endif // BOOST__DATAFLOW__UTILITY__ENABLE_IF_TYPE_HPP
Copied: sandbox/dataflow-rewrite/boost/dataflow/utility/is_type.hpp (from r47744, /sandbox/SOC/2007/signals/boost/dataflow/utility/is_type.hpp)
==============================================================================
--- /sandbox/SOC/2007/signals/boost/dataflow/utility/is_type.hpp (original)
+++ sandbox/dataflow-rewrite/boost/dataflow/utility/is_type.hpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -1,10 +1,10 @@
-// Copyright 2007 Stjepan Rajko.
+// Copyright 2007,2008 Stjepan Rajko.
// Distributed under the Boost Software License, Version 1.0. (See
// accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#ifndef BOOST_DATAFLOW_UTILITY_IS_TYPE_HPP
-#define BOOST_DATAFLOW_UTILITY_IS_TYPE_HPP
+#ifndef BOOST__DATAFLOW__UTILITY__IS_TYPE_HPP
+#define BOOST__DATAFLOW__UTILITY__IS_TYPE_HPP
#include <boost/mpl/bool.hpp>
@@ -12,12 +12,12 @@
namespace utility {
-template<typename T>
-struct is_type
- : public mpl::true_ {};
+ template<typename T>
+ struct is_type
+ : public mpl::true_ {};
} // namespace utility
} } // namespace boost::dataflow
-#endif // BOOST_DATAFLOW_SUPPORT_KEYED_PORT_HPP
+#endif // BOOST__DATAFLOW__UTILITY__IS_TYPE_HPP
Modified: sandbox/dataflow-rewrite/libs/dataflow/build/xcodeide/dataflow.xcodeproj/project.pbxproj
==============================================================================
--- sandbox/dataflow-rewrite/libs/dataflow/build/xcodeide/dataflow.xcodeproj/project.pbxproj (original)
+++ sandbox/dataflow-rewrite/libs/dataflow/build/xcodeide/dataflow.xcodeproj/project.pbxproj 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -78,6 +78,15 @@
/* Begin PBXFileReference section */
08A77AB30E4F91AA00B8793E /* Jamroot */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text; name = Jamroot; path = ../../../../Jamroot; sourceTree = SOURCE_ROOT; };
08A77AB40E4F91AB00B8793E /* LICENSE_1_0.txt */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text; name = LICENSE_1_0.txt; path = ../../../../LICENSE_1_0.txt; sourceTree = SOURCE_ROOT; };
+ 08A77ADB0E4FB06600B8793E /* entity.hpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = entity.hpp; sourceTree = "<group>"; };
+ 08A77ADC0E4FB06600B8793E /* framework.hpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = framework.hpp; sourceTree = "<group>"; };
+ 08A77ADD0E4FB06600B8793E /* traits.hpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = traits.hpp; sourceTree = "<group>"; };
+ 08A77AED0E4FB4C800B8793E /* enable_if_type.hpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = enable_if_type.hpp; sourceTree = "<group>"; };
+ 08A77AEE0E4FB4C800B8793E /* is_type.hpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = is_type.hpp; sourceTree = "<group>"; };
+ 08A77AF20E4FC34B00B8793E /* traits_sequence_intrusive_registration.hpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = traits_sequence_intrusive_registration.hpp; sourceTree = "<group>"; };
+ 08A77B000E4FC51C00B8793E /* test_entity.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = test_entity.cpp; sourceTree = "<group>"; };
+ 08A77B010E4FC51C00B8793E /* Jamfile */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.jam; path = Jamfile; sourceTree = "<group>"; };
+ 08A77B060E4FC58D00B8793E /* Jamfile */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.jam; path = Jamfile; sourceTree = "<group>"; };
/* End PBXFileReference section */
/* Begin PBXGroup section */
@@ -113,6 +122,7 @@
08A77ACC0E4F941C00B8793E /* dataflow */ = {
isa = PBXGroup;
children = (
+ 08A77AEC0E4FB4C800B8793E /* utility */,
08A77ACD0E4F941C00B8793E /* generic */,
);
name = dataflow;
@@ -122,6 +132,36 @@
08A77ACD0E4F941C00B8793E /* generic */ = {
isa = PBXGroup;
children = (
+ 08A77AF10E4FC34B00B8793E /* entity */,
+ 08A77ADB0E4FB06600B8793E /* entity.hpp */,
+ 08A77ADC0E4FB06600B8793E /* framework.hpp */,
+ 08A77ADD0E4FB06600B8793E /* traits.hpp */,
+ );
+ path = generic;
+ sourceTree = "<group>";
+ };
+ 08A77AEC0E4FB4C800B8793E /* utility */ = {
+ isa = PBXGroup;
+ children = (
+ 08A77AED0E4FB4C800B8793E /* enable_if_type.hpp */,
+ 08A77AEE0E4FB4C800B8793E /* is_type.hpp */,
+ );
+ path = utility;
+ sourceTree = "<group>";
+ };
+ 08A77AF10E4FC34B00B8793E /* entity */ = {
+ isa = PBXGroup;
+ children = (
+ 08A77AF20E4FC34B00B8793E /* traits_sequence_intrusive_registration.hpp */,
+ );
+ path = entity;
+ sourceTree = "<group>";
+ };
+ 08A77AFF0E4FC51C00B8793E /* generic */ = {
+ isa = PBXGroup;
+ children = (
+ 08A77B000E4FC51C00B8793E /* test_entity.cpp */,
+ 08A77B060E4FC58D00B8793E /* Jamfile */,
);
path = generic;
sourceTree = "<group>";
@@ -129,6 +169,8 @@
08C675960C13A03E00D85379 /* test */ = {
isa = PBXGroup;
children = (
+ 08A77AFF0E4FC51C00B8793E /* generic */,
+ 08A77B010E4FC51C00B8793E /* Jamfile */,
);
name = test;
path = ../../test;
Copied: sandbox/dataflow-rewrite/libs/dataflow/test/Jamfile (from r47744, /sandbox/SOC/2007/signals/libs/dataflow/test/Jamfile.v2)
==============================================================================
--- /sandbox/SOC/2007/signals/libs/dataflow/test/Jamfile.v2 (original)
+++ sandbox/dataflow-rewrite/libs/dataflow/test/Jamfile 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -7,22 +7,7 @@
project dataflow/test
: requirements
- <include>../../..
- <include>$(BOOST_ROOT)
<define>BOOST_ALL_NO_LIB=1
;
-run test_entity.cpp ;
-run test_port.cpp ;
-run test_unary_op.cpp ;
-run test_binary_op.cpp ;
-run test_complemented_port.cpp ;
-run test_keyed_port.cpp ;
-run test_vector_port.cpp ;
-run test_dynamic_port.cpp ;
-run test_component.cpp ;
-
-build-project signals ;
-build-project blueprint ;
-build-project utility ;
-build-project managed ;
\ No newline at end of file
+build-project generic ;
Copied: sandbox/dataflow-rewrite/libs/dataflow/test/generic/test_entity.cpp (from r47744, /sandbox/SOC/2007/signals/libs/dataflow/test/test_entity.cpp)
==============================================================================
--- /sandbox/SOC/2007/signals/libs/dataflow/test/test_entity.cpp (original)
+++ sandbox/dataflow-rewrite/libs/dataflow/test/generic/test_entity.cpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -3,13 +3,13 @@
// 1.0. (See accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#include <boost/dataflow/support/traits.hpp>
+#include <boost/dataflow/generic/entity.hpp>
#include <boost/test/included/test_exec_monitor.hpp>
namespace df = boost::dataflow;
-typedef df::traits<df::default_tag> my_traits;
+typedef df::traits<df::default_framework> my_traits;
struct entity
{
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- /sandbox/SOC/2007/signals/boost/dataflow/support/tags.hpp (original)
+++ sandbox/dataflow-rewrite/boost/dataflow/generic/framework.hpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -1,97 +1,28 @@
-// Copyright 2007 Stjepan Rajko.
+// Copyright 2007,2008 Stjepan Rajko.
// Distributed under the Boost Software License, Version 1.0. (See
// accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#ifndef BOOST_DATAFLOW_SUPPORT_TAGS_HPP
-#define BOOST_DATAFLOW_SUPPORT_TAGS_HPP
+#ifndef BOOST__DATAFLOW__GENERIC__FRAMEWORK_HPP
+#define BOOST__DATAFLOW__GENERIC__FRAMEWORK_HPP
#include <boost/type_traits/is_base_of.hpp>
namespace boost { namespace dataflow {
-/// The default Tag argument for Dataflow templates.
-struct tag {};
+/// Base class for Framework types.
+struct framework {};
-/// The default Tag argument for Dataflow templates.
-struct default_tag : tag {};
+/// The default Framework argument for Dataflow templates.
+struct default_framework : framework {};
-/// Boolean metafunction determining whether a type is a Tag.
+/// Boolean metafunction determining whether a type is a Framework.
template<typename T>
-struct is_tag
- : public is_base_of<tag, T> {};
+struct is_framework
+ : public is_base_of<framework, T> {};
-/// The default Mechanism argument for Dataflow templates.
-struct default_mechanism {};
-
-/// PortCategory types.
-namespace ports
-{
- struct producer;
- struct consumer;
-
- /// producer PortCategory.
- struct producer
- {
- typedef consumer complement; ///< complement PortCategory type.
- };
-
- /// consumer PortCategory.
- struct consumer
- {
- typedef producer complement; ///< complement PortCategory type.
- };
-}
-
-/*namespace concepts
-{
- struct entity {};
-
- struct port_vector : public entity {};
- struct fusion_port_vector : public port_vector {};
-
- /// PortConcept type specifying the Port concept.
- struct port : public entity {};
- /// PortConcept tag specifying the KeyedPort concept.
- struct vector_port : public port {};
- struct fusion_vector_port : public port, public fusion_port_vector {};
- /// PortConcept tag specifying the KeyedPort concept.
- struct keyed_port : public vector_port {};
- /// PortConcept tag specifying the ComplementedPort concept.
- struct complemented_port : public port {};
- /// ComponentConcept tag specifying the Component concept.
- struct component : port_vector {};
- /// ComponentConcept tag specifying the FusionComponent concept.
- struct fusion_component : public component, public fusion_port_vector {};
-}
-
-template<typename T>
-struct is_concept
- : public is_base_of<concepts::entity, T> {};*/
-
-
-namespace operations {
- /// Tag specifying the connect binary operation.
- struct connect {};
- /// Tag specifying the connect_only binary operation.
- struct connect_only {};
- /// Tag specifying the disconnect binary operation.
- struct disconnect {};
- /// Tag specifying the extract binary operation.
- struct extract {};
-
- /// Tag specifying the disconnect_all unary port operation.
- struct disconnect_all {};
-}
-
-namespace args {
- /// Tag specifying the left direction in binary operations.
- struct left {};
- /// Tag specifying the right direction in binary operations.
- struct right {};
-}
} } // namespace boost::dataflow
-#endif // BOOST_DATAFLOW_SUPPORT_TAGS_HPP
+#endif // BOOST__DATAFLOW__GENERIC__FRAMEWORK__HPP
Copied: sandbox/dataflow-rewrite/boost/dataflow/generic/traits.hpp (from r47744, /sandbox/SOC/2007/signals/boost/dataflow/support/traits.hpp)
==============================================================================
--- /sandbox/SOC/2007/signals/boost/dataflow/support/traits.hpp (original)
+++ sandbox/dataflow-rewrite/boost/dataflow/generic/traits.hpp 2008-08-10 21:03:12 EDT (Sun, 10 Aug 2008)
@@ -1,12 +1,12 @@
-// Copyright 2007 Stjepan Rajko.
+// Copyright 2007,2008 Stjepan Rajko.
// Distributed under the Boost Software License, Version 1.0. (See
// accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#ifndef BOOST_DATAFLOW_SUPPORT_TRAITS_HPP
-#define BOOST_DATAFLOW_SUPPORT_TRAITS_HPP
+#ifndef BOOST__DATAFLOW__GENERIC__TRAITS_HPP
+#define BOOST__DATAFLOW__GENERIC__TRAITS_HPP
-#include <boost/dataflow/support/tags.hpp>
+#include <boost/dataflow/generic/framework.hpp>
#include <boost/dataflow/utility/enable_if_type.hpp>
#include <boost/mpl/assert.hpp>
@@ -20,13 +20,13 @@
namespace boost { namespace dataflow {
/// Convenience class for Traits types.
-template<typename Tag>
+template<typename Framework>
struct traits
{
- /// The Tag of the port.
- typedef Tag tag;
+ /// The Framework of the port.
+ typedef Framework framework;
/// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_tag<Tag> ));
+ BOOST_MPL_ASSERT(( is_framework<Framework> ));
};
namespace detail {
@@ -46,18 +46,18 @@
struct is_traits<Traits,
typename utility::enable_if_type<
utility::all_of<
- typename Traits::tag
+ typename Traits::framework
>,
detail::enable_guard
>::type>
: public mpl::true_
{
/// INTERNAL ONLY
- BOOST_MPL_ASSERT(( is_tag<typename Traits::tag> ));
+ BOOST_MPL_ASSERT(( is_framework<typename Traits::framework> ));
};
/// Metafunction returning the Traits of a type.
-template<typename T, typename Tag=default_tag, typename Enable=void>
+template<typename T, typename Framework=default_framework, typename Enable=void>
struct traits_of
{
#ifdef DOXYGEN_DOCS_BUILD
@@ -71,7 +71,7 @@
template<typename T>
struct traits_of<
T,
- typename T::dataflow_traits::tag,
+ typename T::dataflow_traits::framework,
typename enable_if<
mpl::not_<mpl::is_sequence<typename T::dataflow_traits> >
>::type
@@ -86,12 +86,12 @@
} }
// Specialization allowing intrusive specification of a sequence of Traits.
-#include <boost/dataflow/support/detail/traits_sequence.hpp>
+#include <boost/dataflow/generic/entity/traits_sequence_intrusive_registration.hpp>
namespace boost { namespace dataflow {
/// Allows registration of Traits for all cv-qualified versions of a type.
-template<typename T, typename Tag=default_tag, typename Enable=void>
+template<typename T, typename Framework=default_framework, typename Enable=void>
struct register_traits
{};
@@ -99,14 +99,14 @@
// Specialization allowing non-intrusive specification of the Traits.
/// INTERNAL ONLY
-template<typename T, typename Tag>
+template<typename T, typename Framework>
struct traits_of<
T,
- Tag,
+ Framework,
typename utility::enable_if_type<
typename register_traits<
typename remove_cv<T>::type,
- Tag
+ Framework
>::type
>::type
>
@@ -115,35 +115,12 @@
typedef
typename register_traits<
typename remove_cv<T>::type,
- Tag
+ Framework
>::type type;
/// INTERNAL ONLY
BOOST_MPL_ASSERT(( is_traits<type> ));
};
-/// Boolean Metafunction determining whether a type has traits.
-template<typename T, typename Tag=default_tag, typename Enable=void>
-struct is_entity : public mpl::false_
-{
-#ifdef DOXYGEN_DOCS_BUILD
- /// Integral Constant value type
- typedef bool value_type;
- /// true if T models Entity, false otherwise.
- typedef detail::unspecified value;
- /// Integral Constant
- typedef detail::unspecified type;
-#endif
-};
-
-/// INTERNAL ONLY
-template<typename T, typename Tag>
-struct is_entity<
- T,
- Tag,
- typename utility::enable_if_type<typename traits_of<T, Tag>::type>::type >
- : public mpl::true_
-{};
-
} } // namespace boost::dataflow
/// Macro simplifying non-intrusive specification of a type's Traits.
@@ -152,7 +129,7 @@
template<> \
struct register_traits< \
Type, \
- Traits::tag> \
+ Traits::framework> \
{ \
typedef Traits type; \
BOOST_MPL_ASSERT(( is_traits<type> )); \
@@ -166,7 +143,7 @@
template<typename Type> \
struct register_traits< \
Type, \
- typename Traits::tag, \
+ typename Traits::framework, \
typename boost::enable_if< Cond >::type> \
{ \
typedef Traits type; \
@@ -174,4 +151,4 @@
}; \
}}
-#endif // BOOST_DATAFLOW_SUPPORT_TRAITS_HPP
+#endif // BOOST__DATAFLOW__GENERIC__TRAITS_HPP
Copied: sandbox/dataflow-rewrite/boost/dataflow/utility/enable_if_type.hpp (from r47744, /sandbox/SOC/2007/signals/boost/dataflow/utility/enable_if_type.hpp)
==============================================================================